@@ -45,8 +45,10 @@ import xml.dom.minidom
 
 from urlparse import urlparse, urljoin, urldefrag
 from datetime import date, time, datetime
-from isodate import parse_time, parse_date, parse_datetime
 from re import sub, compile
+from collections import defaultdict
+
+from isodate import parse_time, parse_date, parse_datetime
 
 
 try:
@@ -205,7 +207,7 @@ class URIRef(Identifier):
                     value += "#"
 
         if not _is_valid_uri(value): 
-            raise Exception('%s does not look like a valid URI, perhaps you want to urlencode it?'%value)
+            _LOGGER.warning('%s does not look like a valid URI, trying to serialize this will break.'%value)
 
 
         try:
@@ -218,6 +220,9 @@ class URIRef(Identifier):
         return unicode(self)
 
     def n3(self, namespace_manager = None):
+        if not _is_valid_uri(self): 
+            raise Exception('"%s" does not look like a valid URI, I cannot serialize this as N3/Turtle. Perhaps you wanted to urlencode it?'%self)
+
         if namespace_manager: 
             return namespace_manager.normalizeUri(self)
         else: 
@@ -1560,7 +1565,15 @@ class Statement(Node, tuple):
 
 # Nodes are ordered like this
 # See http://www.w3.org/TR/sparql11-query/#modOrderBy
-_ORDERING = dict(map(reversed, enumerate([BNode, Variable, URIRef, Literal])))
+# we leave "space" for more subclasses of Node elsewhere
+# default-dict to grazefully fail for new subclasses
+_ORDERING = defaultdict(int)
+_ORDERING.update({ 
+    BNode: 10, 
+    Variable: 20, 
+    URIRef: 30, 
+    Literal: 40 
+    })
 
 
 def _isEqualXMLNode(node, other):
